//
// Copyright (c) 2002-2010 The ANGLE Project Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
//

//
// This file contains the posix specific functions
//
#include "compiler/osinclude.h"

#if !defined(ANGLE_OS_AROS)
#error Trying to build an aros specific file in a non-aros build.
#endif

/* Poor-mans TLS implemenation */
volatile BYTE   slotstatus[SLOTCOUNT] = {0};
void *          slot[SLOTCOUNT] = {NULL};

//
// Thread Local Storage Operations
//
OS_TLSIndex OS_AllocTLSIndex()
{
    /* This code is missing semaphore protection for iterating the list */
    for (int i = 0; i< SLOTCOUNT; i++)
        if (slotstatus[i] == 0)
        {
            slotstatus[i] = 1;
            return i;
        }

    return OS_INVALID_TLS_INDEX;
}


bool OS_SetTLSValue(OS_TLSIndex nIndex, void *lpvValue)
{
    if (nIndex >= SLOTCOUNT)
        return false;

    slot[nIndex] = lpvValue;
    return true;
}


bool OS_FreeTLSIndex(OS_TLSIndex nIndex)
{
    if (nIndex >= SLOTCOUNT)
        return false;

    slotstatus[nIndex] = 0;
    return true;
}
